==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/ManagementPolicyActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.ManagementPolicyActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Actions are applied to the filtered blobs when the execution condition is met.
 * @property baseBlob The management policy action for base blob
 * @property snapshot The management policy action for snapshot
 * @property version The management policy action for version
 */
public data class ManagementPolicyActionArgs(
    public val baseBlob: Output<ManagementPolicyBaseBlobArgs>? = null,
    public val snapshot: Output<ManagementPolicySnapShotArgs>? = null,
    public val version: Output<ManagementPolicyVersionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.ManagementPolicyActionArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.ManagementPolicyActionArgs =
        com.pulumi.azurenative.storage.inputs.ManagementPolicyActionArgs.builder()
            .baseBlob(baseBlob?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .snapshot(snapshot?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .version(version?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ManagementPolicyActionArgs].
 */
@PulumiTagMarker
public class ManagementPolicyActionArgsBuilder internal constructor() {
    private var baseBlob: Output<ManagementPolicyBaseBlobArgs>? = null

    private var snapshot: Output<ManagementPolicySnapShotArgs>? = null

    private var version: Output<ManagementPolicyVersionArgs>? = null

    /**
     * @param value The management policy action for base blob
     */
    @JvmName("opdpyafnuiutcmhe")
    public suspend fun baseBlob(`value`: Output<ManagementPolicyBaseBlobArgs>) {
        this.baseBlob = value
    }

    /**
     * @param value The management policy action for snapshot
     */
    @JvmName("uitgssjocpepfrvq")
    public suspend fun snapshot(`value`: Output<ManagementPolicySnapShotArgs>) {
        this.snapshot = value
    }

    /**
     * @param value The management policy action for version
     */
    @JvmName("qxurmqvqodejeaxa")
    public suspend fun version(`value`: Output<ManagementPolicyVersionArgs>) {
        this.version = value
    }

    /**
     * @param value The management policy action for base blob
     */
    @JvmName("awelpuglfdshsurk")
    public suspend fun baseBlob(`value`: ManagementPolicyBaseBlobArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baseBlob = mapped
    }

    /**
     * @param argument The management policy action for base blob
     */
    @JvmName("ofyjtnekbltpkbug")
    public suspend fun baseBlob(argument: suspend ManagementPolicyBaseBlobArgsBuilder.() -> Unit) {
        val toBeMapped = ManagementPolicyBaseBlobArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baseBlob = mapped
    }

    /**
     * @param value The management policy action for snapshot
     */
    @JvmName("vqdgfdmhbepbyvso")
    public suspend fun snapshot(`value`: ManagementPolicySnapShotArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.snapshot = mapped
    }

    /**
     * @param argument The management policy action for snapshot
     */
    @JvmName("ewbbnqeucucqkuka")
    public suspend fun snapshot(argument: suspend ManagementPolicySnapShotArgsBuilder.() -> Unit) {
        val toBeMapped = ManagementPolicySnapShotArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.snapshot = mapped
    }

    /**
     * @param value The management policy action for version
     */
    @JvmName("eaijrjiobwadudtf")
    public suspend fun version(`value`: ManagementPolicyVersionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    /**
     * @param argument The management policy action for version
     */
    @JvmName("nfftqknuwcfumeyw")
    public suspend fun version(argument: suspend ManagementPolicyVersionArgsBuilder.() -> Unit) {
        val toBeMapped = ManagementPolicyVersionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.version = mapped
    }

    internal fun build(): ManagementPolicyActionArgs = ManagementPolicyActionArgs(
        baseBlob = baseBlob,
        snapshot = snapshot,
        version = version,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/ManagementPolicyActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.ManagementPolicyActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Actions are applied to the filtered blobs when the execution condition is met.
 * @property baseBlob The management policy action for base blob
 * @property snapshot The management policy action for snapshot
 * @property version The management policy action for version
 */
public data class ManagementPolicyActionArgs(
    public val baseBlob: Output<ManagementPolicyBaseBlobArgs>? = null,
    public val snapshot: Output<ManagementPolicySnapShotArgs>? = null,
    public val version: Output<ManagementPolicyVersionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.ManagementPolicyActionArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.ManagementPolicyActionArgs =
        com.pulumi.azurenative.storage.inputs.ManagementPolicyActionArgs.builder()
            .baseBlob(baseBlob?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .snapshot(snapshot?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .version(version?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ManagementPolicyActionArgs].
 */
@PulumiTagMarker
public class ManagementPolicyActionArgsBuilder internal constructor() {
    private var baseBlob: Output<ManagementPolicyBaseBlobArgs>? = null

    private var snapshot: Output<ManagementPolicySnapShotArgs>? = null

    private var version: Output<ManagementPolicyVersionArgs>? = null

    /**
     * @param value The management policy action for base blob
     */
    @JvmName("btrtsksndtjigrhe")
    public suspend fun baseBlob(`value`: Output<ManagementPolicyBaseBlobArgs>) {
        this.baseBlob = value
    }

    /**
     * @param value The management policy action for snapshot
     */
    @JvmName("auhfkpbxbopqdpjf")
    public suspend fun snapshot(`value`: Output<ManagementPolicySnapShotArgs>) {
        this.snapshot = value
    }

    /**
     * @param value The management policy action for version
     */
    @JvmName("eeukfkrfjnoubtfx")
    public suspend fun version(`value`: Output<ManagementPolicyVersionArgs>) {
        this.version = value
    }

    /**
     * @param value The management policy action for base blob
     */
    @JvmName("aqvmrlwxfqoyohhm")
    public suspend fun baseBlob(`value`: ManagementPolicyBaseBlobArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baseBlob = mapped
    }

    /**
     * @param argument The management policy action for base blob
     */
    @JvmName("jufchlvorugafdlb")
    public suspend fun baseBlob(argument: suspend ManagementPolicyBaseBlobArgsBuilder.() -> Unit) {
        val toBeMapped = ManagementPolicyBaseBlobArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baseBlob = mapped
    }

    /**
     * @param value The management policy action for snapshot
     */
    @JvmName("hscnkhmbbkyosjdn")
    public suspend fun snapshot(`value`: ManagementPolicySnapShotArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.snapshot = mapped
    }

    /**
     * @param argument The management policy action for snapshot
     */
    @JvmName("xukmctycxdlrotec")
    public suspend fun snapshot(argument: suspend ManagementPolicySnapShotArgsBuilder.() -> Unit) {
        val toBeMapped = ManagementPolicySnapShotArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.snapshot = mapped
    }

    /**
     * @param value The management policy action for version
     */
    @JvmName("duihiwultesseocu")
    public suspend fun version(`value`: ManagementPolicyVersionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    /**
     * @param argument The management policy action for version
     */
    @JvmName("jqrpvkebvixcleum")
    public suspend fun version(argument: suspend ManagementPolicyVersionArgsBuilder.() -> Unit) {
        val toBeMapped = ManagementPolicyVersionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.version = mapped
    }

    internal fun build(): ManagementPolicyActionArgs = ManagementPolicyActionArgs(
        baseBlob = baseBlob,
        snapshot = snapshot,
        version = version,
    )
}
